/*
 * This file was generated by orbit-idl-2 - DO NOT EDIT!
 */

#include <string.h>
#define ORBIT2_STUBS_API
#define ORBIT_IDL_C_COMMON
#define Evolution_DataServer_Mail_COMMON
#include "Evolution-DataServer-Mail.h"

static const CORBA_unsigned_long ORBit_zero_int = 0;

#ifndef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
void _ORBIT_skel_small_Evolution_Mail_MessageStream_next(POA_Evolution_Mail_MessageStream             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
Evolution_Mail_Buffer* (*_impl_next)(PortableServer_Servant _servant, const CORBA_long size, CORBA_Environment *ev)) {
*(Evolution_Mail_Buffer* *)_o_retval = _impl_next (_o_servant, *(const CORBA_long *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_MessageStream_dispose(POA_Evolution_Mail_MessageStream             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_dispose)(PortableServer_Servant _servant, CORBA_Environment *ev)) {
_impl_dispose (_o_servant, _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_MessageIterator_next(POA_Evolution_Mail_MessageIterator             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
Evolution_Mail_MessageInfos* (*_impl_next)(PortableServer_Servant _servant, const CORBA_long limit, CORBA_Environment *ev)) {
*(Evolution_Mail_MessageInfos* *)_o_retval = _impl_next (_o_servant, *(const CORBA_long *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_MessageIterator_dispose(POA_Evolution_Mail_MessageIterator             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_dispose)(PortableServer_Servant _servant, CORBA_Environment *ev)) {
_impl_dispose (_o_servant, _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_SessionListener_changed(POA_Evolution_Mail_SessionListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_changed)(PortableServer_Servant _servant, const Evolution_Mail_Session session, const Evolution_Mail_SessionChanges* changes, CORBA_Environment *ev)) {
_impl_changed (_o_servant, *(const Evolution_Mail_Session *)_o_args[0], (const CORBA_sequence_Evolution_Mail_SessionChange*)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_SessionListener_shutdown(POA_Evolution_Mail_SessionListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_shutdown)(PortableServer_Servant _servant, const Evolution_Mail_Session session, CORBA_Environment *ev)) {
_impl_shutdown (_o_servant, *(const Evolution_Mail_Session *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_StoreListener_changed(POA_Evolution_Mail_StoreListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_changed)(PortableServer_Servant _servant, const Evolution_Mail_Store store, const Evolution_Mail_StoreChanges* changes, CORBA_Environment *ev)) {
_impl_changed (_o_servant, *(const Evolution_Mail_Store *)_o_args[0], (const CORBA_sequence_Evolution_Mail_StoreChange*)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_FolderListener_changed(POA_Evolution_Mail_FolderListener             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_changed)(PortableServer_Servant _servant, const Evolution_Mail_Folder folder, const Evolution_Mail_FolderChanges* changes, CORBA_Environment *ev)) {
_impl_changed (_o_servant, *(const Evolution_Mail_Folder *)_o_args[0], (const CORBA_sequence_Evolution_Mail_FolderChange*)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_Session_getProperties(POA_Evolution_Mail_Session             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
CORBA_boolean (*_impl_getProperties)(PortableServer_Servant _servant, const Evolution_Mail_PropertyNames* names, Evolution_Mail_Properties** props, CORBA_Environment *ev)) {
*(CORBA_boolean *)_o_retval = _impl_getProperties (_o_servant, (const CORBA_sequence_Evolution_Mail_PropertyName*)_o_args[0], (CORBA_sequence_Evolution_Mail_Property**)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_Session_getStores(POA_Evolution_Mail_Session             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
Evolution_Mail_StoreInfos* (*_impl_getStores)(PortableServer_Servant _servant, const CORBA_char * pattern, const Evolution_Mail_StoreListener listener, CORBA_Environment *ev)) {
*(Evolution_Mail_StoreInfos* *)_o_retval = _impl_getStores (_o_servant, *(const CORBA_char * *)_o_args[0], *(const Evolution_Mail_StoreListener *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_Session_addListener(POA_Evolution_Mail_Session             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_addListener)(PortableServer_Servant _servant, const Evolution_Mail_SessionListener listener, CORBA_Environment *ev)) {
_impl_addListener (_o_servant, *(const Evolution_Mail_SessionListener *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_Session_removeListener(POA_Evolution_Mail_Session             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_removeListener)(PortableServer_Servant _servant, const Evolution_Mail_SessionListener listener, CORBA_Environment *ev)) {
_impl_removeListener (_o_servant, *(const Evolution_Mail_SessionListener *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_Store_getProperties(POA_Evolution_Mail_Store             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
CORBA_boolean (*_impl_getProperties)(PortableServer_Servant _servant, const Evolution_Mail_PropertyNames* names, Evolution_Mail_Properties** props, CORBA_Environment *ev)) {
*(CORBA_boolean *)_o_retval = _impl_getProperties (_o_servant, (const CORBA_sequence_Evolution_Mail_PropertyName*)_o_args[0], (CORBA_sequence_Evolution_Mail_Property**)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_Store_getFolders(POA_Evolution_Mail_Store             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
Evolution_Mail_FolderInfos* (*_impl_getFolders)(PortableServer_Servant _servant, const CORBA_char * pattern, const Evolution_Mail_FolderListener listener, CORBA_Environment *ev)) {
*(Evolution_Mail_FolderInfos* *)_o_retval = _impl_getFolders (_o_servant, *(const CORBA_char * *)_o_args[0], *(const Evolution_Mail_FolderListener *)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_Store_sendMessage(POA_Evolution_Mail_Store             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_sendMessage)(PortableServer_Servant _servant, const Evolution_Mail_MessageStream msg, CORBA_Environment *ev)) {
_impl_sendMessage (_o_servant, *(const Evolution_Mail_MessageStream *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_Folder_getProperties(POA_Evolution_Mail_Folder             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
CORBA_boolean (*_impl_getProperties)(PortableServer_Servant _servant, const Evolution_Mail_PropertyNames* names, Evolution_Mail_Properties** props, CORBA_Environment *ev)) {
*(CORBA_boolean *)_o_retval = _impl_getProperties (_o_servant, (const CORBA_sequence_Evolution_Mail_PropertyName*)_o_args[0], (CORBA_sequence_Evolution_Mail_Property**)_o_args[1], _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_Folder_getMessages(POA_Evolution_Mail_Folder             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
Evolution_Mail_MessageIterator (*_impl_getMessages)(PortableServer_Servant _servant, const CORBA_char * pattern, CORBA_Environment *ev)) {
*(Evolution_Mail_MessageIterator *)_o_retval = _impl_getMessages (_o_servant, *(const CORBA_char * *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_Folder_changeMessages(POA_Evolution_Mail_Folder             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_changeMessages)(PortableServer_Servant _servant, const Evolution_Mail_MessageInfoSets* infos, CORBA_Environment *ev)) {
_impl_changeMessages (_o_servant, (const CORBA_sequence_Evolution_Mail_MessageInfoSet*)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_Folder_getMessage(POA_Evolution_Mail_Folder             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
Evolution_Mail_MessageStream (*_impl_getMessage)(PortableServer_Servant _servant, const CORBA_char * uid, CORBA_Environment *ev)) {
*(Evolution_Mail_MessageStream *)_o_retval = _impl_getMessage (_o_servant, *(const CORBA_char * *)_o_args[0], _o_ev);
}
void _ORBIT_skel_small_Evolution_Mail_Folder_appendMessage(POA_Evolution_Mail_Folder             *_o_servant, gpointer            _o_retval,gpointer           *_o_args,CORBA_Context       _o_ctx,CORBA_Environment  *_o_ev,
void (*_impl_appendMessage)(PortableServer_Servant _servant, const Evolution_Mail_MessageInfoSet* info, const Evolution_Mail_MessageStream msg, CORBA_Environment *ev)) {
_impl_appendMessage (_o_servant, (const Evolution_Mail_MessageInfoSet*)_o_args[0], *(const Evolution_Mail_MessageStream *)_o_args[1], _o_ev);
}

#endif
#if ( (TC_IMPL_TC_Evolution_Mail_PropertyName_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyName_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_PropertyName)
#define TC_DEF_TC_Evolution_Mail_PropertyName 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array5[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_PropertyName_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array5,
CORBA_OBJECT_NIL,
"PropertyName",
"IDL:Evolution/Mail/PropertyName:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_CORBA_string_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_CORBA_string)
#define TC_DEF_TC_CORBA_sequence_CORBA_string 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array8[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_string_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array8,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_PropertyName)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_PropertyName 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array11[] = {(CORBA_TypeCode)&TC_Evolution_Mail_PropertyName_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_PropertyName_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array11,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_PropertyName_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_PropertyName)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_PropertyName 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array18[] = {(CORBA_TypeCode)&TC_Evolution_Mail_PropertyName_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_PropertyName_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array18,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_PropertyNames_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_PropertyNames_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_PropertyNames)
#define TC_DEF_TC_Evolution_Mail_PropertyNames 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array21[] = {(CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_PropertyName_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_PropertyNames_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array21,
CORBA_OBJECT_NIL,
"PropertyNames",
"IDL:Evolution/Mail/PropertyNames:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_Property_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_Property_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_Property_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_Property_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_Property_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_Property_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_Property_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_Property_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_Property_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_Property_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_Property_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_Property_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Property_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_Property_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Property_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_Property_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_Property_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_Property_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_Property_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_Property_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_Property_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_Property_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_Property_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Property_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_Property_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_Property)
#define TC_DEF_TC_Evolution_Mail_Property 1
static const char *anon_subnames_array23[] = {"name", "value"};
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array24[] = {(CORBA_TypeCode)&TC_Evolution_Mail_PropertyName_struct, (CORBA_TypeCode)&TC_CORBA_any_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Property_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_struct,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_STRUCT, MAX (ORBIT_ALIGNOF_CORBA_POINTER, 1)),
0,
2
,
(CORBA_TypeCode *)anon_subtypes_array24,
CORBA_OBJECT_NIL,
"Property",
"IDL:Evolution/Mail/Property:1.0",
(char **)anon_subnames_array23,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_Property)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_Property 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array27[] = {(CORBA_TypeCode)&TC_Evolution_Mail_Property_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_Property_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array27,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Property_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_Property)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_Property 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array34[] = {(CORBA_TypeCode)&TC_Evolution_Mail_Property_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_Property_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array34,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_Properties_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_Properties_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_Properties)
#define TC_DEF_TC_Evolution_Mail_Properties 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array37[] = {(CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_Property_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Properties_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array37,
CORBA_OBJECT_NIL,
"Properties",
"IDL:Evolution/Mail/Properties:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_ErrorType_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_ErrorType_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_ErrorType)
#define TC_DEF_TC_Evolution_Mail_ErrorType 1
static const char *anon_subnames_array39[] = {"SYSTEM_ERROR", "CAMEL_ERROR", "FAILED", "NOT_SUPPORTED", "NO_PERMISSION"};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_ErrorType_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_enum,
0,
0,
ORBIT_ALIGNOF_CORBA_LONG,
0,
5
,
NULL,
CORBA_OBJECT_NIL,
"ErrorType",
"IDL:Evolution/Mail/ErrorType:1.0",
(char **)anon_subnames_array39,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_MailException_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_MailException_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_MailException)
#define TC_DEF_TC_Evolution_Mail_MailException 1
static const char *anon_subnames_array42[] = {"id", "desc"};
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array43[] = {(CORBA_TypeCode)&TC_Evolution_Mail_ErrorType_struct, (CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_MailException_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_except,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, 1)),
0,
2
,
(CORBA_TypeCode *)anon_subtypes_array43,
CORBA_OBJECT_NIL,
"MailException",
"IDL:Evolution/Mail/MailException:1.0",
(char **)anon_subnames_array42,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_CORBA_Object_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_CORBA_Object)
#define TC_DEF_TC_CORBA_sequence_CORBA_Object 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array46[] = {(CORBA_TypeCode)&TC_CORBA_Object_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_Object_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array46,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_Folder)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_Folder 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array49[] = {(CORBA_TypeCode)&TC_Evolution_Mail_Folder_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_Folder_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array49,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Folder_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_Folder)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_Folder 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array56[] = {(CORBA_TypeCode)&TC_Evolution_Mail_Folder_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_Folder_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array56,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_Folders_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_Folders_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_Folders)
#define TC_DEF_TC_Evolution_Mail_Folders 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array59[] = {(CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_Folder_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Folders_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array59,
CORBA_OBJECT_NIL,
"Folders",
"IDL:Evolution/Mail/Folders:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_FolderInfo_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfo_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_FolderInfo)
#define TC_DEF_TC_Evolution_Mail_FolderInfo 1
static const char *anon_subnames_array61[] = {"name", "full_name", "folder"};
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array62[] = {(CORBA_TypeCode)&TC_CORBA_string_struct, (CORBA_TypeCode)&TC_CORBA_string_struct, (CORBA_TypeCode)&TC_Evolution_Mail_Folder_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_FolderInfo_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_struct,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
3
,
(CORBA_TypeCode *)anon_subtypes_array62,
CORBA_OBJECT_NIL,
"FolderInfo",
"IDL:Evolution/Mail/FolderInfo:1.0",
(char **)anon_subnames_array61,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_FolderInfo)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_FolderInfo 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array65[] = {(CORBA_TypeCode)&TC_Evolution_Mail_FolderInfo_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_FolderInfo_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array65,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderInfo_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_FolderInfo)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_FolderInfo 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array72[] = {(CORBA_TypeCode)&TC_Evolution_Mail_FolderInfo_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_FolderInfo_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array72,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_FolderInfos_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_FolderInfos_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_FolderInfos)
#define TC_DEF_TC_Evolution_Mail_FolderInfos 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array75[] = {(CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_FolderInfo_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_FolderInfos_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array75,
CORBA_OBJECT_NIL,
"FolderInfos",
"IDL:Evolution/Mail/FolderInfos:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_CORBA_Object_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_Object_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_CORBA_Object)
#define TC_DEF_TC_CORBA_sequence_CORBA_Object 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array78[] = {(CORBA_TypeCode)&TC_CORBA_Object_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_Object_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array78,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_Store)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_Store 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array81[] = {(CORBA_TypeCode)&TC_Evolution_Mail_Store_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_Store_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array81,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_Store_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_Store)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_Store 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array88[] = {(CORBA_TypeCode)&TC_Evolution_Mail_Store_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_Store_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array88,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_Stores_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_Stores_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_Stores)
#define TC_DEF_TC_Evolution_Mail_Stores 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array91[] = {(CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_Store_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Stores_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array91,
CORBA_OBJECT_NIL,
"Stores",
"IDL:Evolution/Mail/Stores:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_StoreInfo_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfo_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_StoreInfo)
#define TC_DEF_TC_Evolution_Mail_StoreInfo 1
static const char *anon_subnames_array93[] = {"name", "uid", "store"};
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array94[] = {(CORBA_TypeCode)&TC_CORBA_string_struct, (CORBA_TypeCode)&TC_CORBA_string_struct, (CORBA_TypeCode)&TC_Evolution_Mail_Store_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_StoreInfo_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_struct,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
3
,
(CORBA_TypeCode *)anon_subtypes_array94,
CORBA_OBJECT_NIL,
"StoreInfo",
"IDL:Evolution/Mail/StoreInfo:1.0",
(char **)anon_subnames_array93,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_StoreInfo)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_StoreInfo 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array97[] = {(CORBA_TypeCode)&TC_Evolution_Mail_StoreInfo_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_StoreInfo_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array97,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreInfo_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_StoreInfo)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_StoreInfo 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array104[] = {(CORBA_TypeCode)&TC_Evolution_Mail_StoreInfo_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_StoreInfo_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array104,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_StoreInfos_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_StoreInfos_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_StoreInfos)
#define TC_DEF_TC_Evolution_Mail_StoreInfos 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array107[] = {(CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_StoreInfo_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_StoreInfos_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array107,
CORBA_OBJECT_NIL,
"StoreInfos",
"IDL:Evolution/Mail/StoreInfos:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_UserFlag_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlag_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_UserFlag)
#define TC_DEF_TC_Evolution_Mail_UserFlag 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array114[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_UserFlag_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array114,
CORBA_OBJECT_NIL,
"UserFlag",
"IDL:Evolution/Mail/UserFlag:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_CORBA_string_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_string_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_CORBA_string)
#define TC_DEF_TC_CORBA_sequence_CORBA_string 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array117[] = {(CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_string_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array117,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_UserFlag)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_UserFlag 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array120[] = {(CORBA_TypeCode)&TC_Evolution_Mail_UserFlag_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_UserFlag_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array120,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserFlag_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_UserFlag)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_UserFlag 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array127[] = {(CORBA_TypeCode)&TC_Evolution_Mail_UserFlag_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_UserFlag_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array127,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_UserFlags_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_UserFlags_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_UserFlags)
#define TC_DEF_TC_Evolution_Mail_UserFlags 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array130[] = {(CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_UserFlag_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_UserFlags_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array130,
CORBA_OBJECT_NIL,
"UserFlags",
"IDL:Evolution/Mail/UserFlags:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_UserTag_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_UserTag_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_UserTag)
#define TC_DEF_TC_Evolution_Mail_UserTag 1
static const char *anon_subnames_array132[] = {"name", "value"};
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array133[] = {(CORBA_TypeCode)&TC_CORBA_string_struct, (CORBA_TypeCode)&TC_CORBA_string_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_UserTag_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_struct,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
2
,
(CORBA_TypeCode *)anon_subtypes_array133,
CORBA_OBJECT_NIL,
"UserTag",
"IDL:Evolution/Mail/UserTag:1.0",
(char **)anon_subnames_array132,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_UserTag)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_UserTag 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array136[] = {(CORBA_TypeCode)&TC_Evolution_Mail_UserTag_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_UserTag_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array136,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_UserTag_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_UserTag)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_UserTag 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array143[] = {(CORBA_TypeCode)&TC_Evolution_Mail_UserTag_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_UserTag_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array143,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_UserTags_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_UserTags_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_UserTags)
#define TC_DEF_TC_Evolution_Mail_UserTags 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array146[] = {(CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_UserTag_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_UserTags_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array146,
CORBA_OBJECT_NIL,
"UserTags",
"IDL:Evolution/Mail/UserTags:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_MessageInfo_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfo_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_MessageInfo)
#define TC_DEF_TC_Evolution_Mail_MessageInfo 1
static const char *anon_subnames_array148[] = {"uid", "subject", "to", "from", "flags", "userFlags", "userTags"};
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array149[] = {(CORBA_TypeCode)&TC_CORBA_string_struct, (CORBA_TypeCode)&TC_CORBA_string_struct, (CORBA_TypeCode)&TC_CORBA_string_struct, (CORBA_TypeCode)&TC_CORBA_string_struct, (CORBA_TypeCode)&TC_CORBA_long_struct, (CORBA_TypeCode)&TC_Evolution_Mail_UserFlags_struct, (CORBA_TypeCode)&TC_Evolution_Mail_UserTags_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_MessageInfo_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_struct,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_STRUCT, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_POINTER, 1))),
0,
7
,
(CORBA_TypeCode *)anon_subtypes_array149,
CORBA_OBJECT_NIL,
"MessageInfo",
"IDL:Evolution/Mail/MessageInfo:1.0",
(char **)anon_subnames_array148,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_MessageInfo)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_MessageInfo 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array152[] = {(CORBA_TypeCode)&TC_Evolution_Mail_MessageInfo_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_MessageInfo_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array152,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfo_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_MessageInfo)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_MessageInfo 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array159[] = {(CORBA_TypeCode)&TC_Evolution_Mail_MessageInfo_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_MessageInfo_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array159,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_MessageInfos_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfos_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_MessageInfos)
#define TC_DEF_TC_Evolution_Mail_MessageInfos 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array162[] = {(CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_MessageInfo_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_MessageInfos_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array162,
CORBA_OBJECT_NIL,
"MessageInfos",
"IDL:Evolution/Mail/MessageInfos:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSet_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_MessageInfoSet)
#define TC_DEF_TC_Evolution_Mail_MessageInfoSet 1
static const char *anon_subnames_array164[] = {"uid", "flagSet", "flagMask", "userFlagSet", "userFlagUnset", "userTags"};
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array165[] = {(CORBA_TypeCode)&TC_CORBA_string_struct, (CORBA_TypeCode)&TC_CORBA_long_struct, (CORBA_TypeCode)&TC_CORBA_long_struct, (CORBA_TypeCode)&TC_Evolution_Mail_UserFlags_struct, (CORBA_TypeCode)&TC_Evolution_Mail_UserFlags_struct, (CORBA_TypeCode)&TC_Evolution_Mail_UserTags_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_MessageInfoSet_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_struct,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_STRUCT, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_POINTER, 1))),
0,
6
,
(CORBA_TypeCode *)anon_subtypes_array165,
CORBA_OBJECT_NIL,
"MessageInfoSet",
"IDL:Evolution/Mail/MessageInfoSet:1.0",
(char **)anon_subnames_array164,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array168[] = {(CORBA_TypeCode)&TC_Evolution_Mail_MessageInfoSet_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array168,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_MessageInfoSet 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array175[] = {(CORBA_TypeCode)&TC_Evolution_Mail_MessageInfoSet_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array175,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_MessageInfoSets_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_MessageInfoSets)
#define TC_DEF_TC_Evolution_Mail_MessageInfoSets 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array178[] = {(CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_MessageInfoSet_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_MessageInfoSets_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array178,
CORBA_OBJECT_NIL,
"MessageInfoSets",
"IDL:Evolution/Mail/MessageInfoSets:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_CORBA_octet_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_CORBA_octet)
#define TC_DEF_TC_CORBA_sequence_CORBA_octet 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array181[] = {(CORBA_TypeCode)&TC_CORBA_octet_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_octet_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array181,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_CORBA_octet_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_CORBA_octet_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_CORBA_octet)
#define TC_DEF_TC_CORBA_sequence_CORBA_octet 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array188[] = {(CORBA_TypeCode)&TC_CORBA_octet_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_CORBA_octet_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array188,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_Buffer_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_Buffer_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_Buffer)
#define TC_DEF_TC_Evolution_Mail_Buffer 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array191[] = {(CORBA_TypeCode)&TC_CORBA_sequence_CORBA_octet_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Buffer_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array191,
CORBA_OBJECT_NIL,
"Buffer",
"IDL:Evolution/Mail/Buffer:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_MessageStream_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_MessageStream_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_MessageStream)
#define TC_DEF_TC_Evolution_Mail_MessageStream 1
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_MessageStream_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_objref,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
"MessageStream",
"IDL:Evolution/Mail/MessageStream:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_MessageIterator_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_MessageIterator_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_MessageIterator)
#define TC_DEF_TC_Evolution_Mail_MessageIterator 1
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_MessageIterator_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_objref,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
"MessageIterator",
"IDL:Evolution/Mail/MessageIterator:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_ChangeType_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_ChangeType_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_ChangeType)
#define TC_DEF_TC_Evolution_Mail_ChangeType 1
static const char *anon_subnames_array199[] = {"ADDED", "REMOVED", "CHANGED"};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_ChangeType_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_enum,
0,
0,
ORBIT_ALIGNOF_CORBA_LONG,
0,
3
,
NULL,
CORBA_OBJECT_NIL,
"ChangeType",
"IDL:Evolution/Mail/ChangeType:1.0",
(char **)anon_subnames_array199,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_SessionChange_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChange_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_SessionChange)
#define TC_DEF_TC_Evolution_Mail_SessionChange 1
static const char *anon_subnames_array202[] = {"type", "stores"};
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array203[] = {(CORBA_TypeCode)&TC_Evolution_Mail_ChangeType_struct, (CORBA_TypeCode)&TC_Evolution_Mail_StoreInfos_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_SessionChange_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_struct,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, MAX (ORBIT_ALIGNOF_CORBA_LONG, 1))),
0,
2
,
(CORBA_TypeCode *)anon_subtypes_array203,
CORBA_OBJECT_NIL,
"SessionChange",
"IDL:Evolution/Mail/SessionChange:1.0",
(char **)anon_subnames_array202,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_SessionChange)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_SessionChange 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array206[] = {(CORBA_TypeCode)&TC_Evolution_Mail_SessionChange_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_SessionChange_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array206,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_SessionChange_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_SessionChange)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_SessionChange 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array213[] = {(CORBA_TypeCode)&TC_Evolution_Mail_SessionChange_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_SessionChange_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array213,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_SessionChanges_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_SessionChanges_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_SessionChanges)
#define TC_DEF_TC_Evolution_Mail_SessionChanges 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array216[] = {(CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_SessionChange_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_SessionChanges_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array216,
CORBA_OBJECT_NIL,
"SessionChanges",
"IDL:Evolution/Mail/SessionChanges:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_StoreChange_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChange_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_StoreChange)
#define TC_DEF_TC_Evolution_Mail_StoreChange 1
static const char *anon_subnames_array218[] = {"type", "folders"};
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array219[] = {(CORBA_TypeCode)&TC_Evolution_Mail_ChangeType_struct, (CORBA_TypeCode)&TC_Evolution_Mail_FolderInfos_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_StoreChange_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_struct,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, MAX (ORBIT_ALIGNOF_CORBA_LONG, 1))),
0,
2
,
(CORBA_TypeCode *)anon_subtypes_array219,
CORBA_OBJECT_NIL,
"StoreChange",
"IDL:Evolution/Mail/StoreChange:1.0",
(char **)anon_subnames_array218,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_StoreChange)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_StoreChange 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array222[] = {(CORBA_TypeCode)&TC_Evolution_Mail_StoreChange_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_StoreChange_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array222,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_StoreChange_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_StoreChange)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_StoreChange 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array229[] = {(CORBA_TypeCode)&TC_Evolution_Mail_StoreChange_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_StoreChange_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array229,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_StoreChanges_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_StoreChanges_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_StoreChanges)
#define TC_DEF_TC_Evolution_Mail_StoreChanges 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array232[] = {(CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_StoreChange_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_StoreChanges_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array232,
CORBA_OBJECT_NIL,
"StoreChanges",
"IDL:Evolution/Mail/StoreChanges:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_FolderChange_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChange_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_FolderChange)
#define TC_DEF_TC_Evolution_Mail_FolderChange 1
static const char *anon_subnames_array234[] = {"type", "messages"};
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array235[] = {(CORBA_TypeCode)&TC_Evolution_Mail_ChangeType_struct, (CORBA_TypeCode)&TC_Evolution_Mail_MessageInfos_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_FolderChange_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_struct,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, MAX (ORBIT_ALIGNOF_CORBA_LONG, 1))),
0,
2
,
(CORBA_TypeCode *)anon_subtypes_array235,
CORBA_OBJECT_NIL,
"FolderChange",
"IDL:Evolution/Mail/FolderChange:1.0",
(char **)anon_subnames_array234,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_FolderChange)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_FolderChange 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array238[] = {(CORBA_TypeCode)&TC_Evolution_Mail_FolderChange_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_FolderChange_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array238,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_0 == 'E') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_1 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_2 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_3 == 'l') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_4 == 'u') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_5 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_6 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_7 == 'o') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_8 == 'n') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_9 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_10 == 'D') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_11 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_12 == 't') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_13 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_14 == 'S') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_15 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_16 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_17 == 'v') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_18 == 'e') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_19 == 'r') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_20 == '_') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_21 == 'M') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_22 == 'a') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_23 == 'i') \
&& (TC_IMPL_TC_CORBA_sequence_Evolution_Mail_FolderChange_24 == 'l') \
) && !defined(TC_DEF_TC_CORBA_sequence_Evolution_Mail_FolderChange)
#define TC_DEF_TC_CORBA_sequence_Evolution_Mail_FolderChange 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array245[] = {(CORBA_TypeCode)&TC_Evolution_Mail_FolderChange_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_CORBA_sequence_Evolution_Mail_FolderChange_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_sequence,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array245,
CORBA_OBJECT_NIL,
NULL,
NULL,
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_FolderChanges_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_FolderChanges_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_FolderChanges)
#define TC_DEF_TC_Evolution_Mail_FolderChanges 1
static ORBIT2_MAYBE_CONST CORBA_TypeCode anon_subtypes_array248[] = {(CORBA_TypeCode)&TC_CORBA_sequence_Evolution_Mail_FolderChange_struct};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_FolderChanges_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_alias,
0,
0,
MAX (ORBIT_ALIGNOF_CORBA_POINTER, MAX (ORBIT_ALIGNOF_CORBA_LONG, MAX (ORBIT_ALIGNOF_CORBA_STRUCT, 1))),
0,
1
,
(CORBA_TypeCode *)anon_subtypes_array248,
CORBA_OBJECT_NIL,
"FolderChanges",
"IDL:Evolution/Mail/FolderChanges:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_SessionListener_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_SessionListener_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_SessionListener)
#define TC_DEF_TC_Evolution_Mail_SessionListener 1
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_SessionListener_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_objref,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
"SessionListener",
"IDL:Evolution/Mail/SessionListener:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_StoreListener_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_StoreListener_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_StoreListener)
#define TC_DEF_TC_Evolution_Mail_StoreListener 1
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_StoreListener_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_objref,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
"StoreListener",
"IDL:Evolution/Mail/StoreListener:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_FolderListener_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_FolderListener_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_FolderListener)
#define TC_DEF_TC_Evolution_Mail_FolderListener 1
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_FolderListener_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_objref,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
"FolderListener",
"IDL:Evolution/Mail/FolderListener:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_Session_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_Session_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_Session_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_Session_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_Session_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_Session_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_Session_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_Session_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_Session_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_Session_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_Session_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_Session_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Session_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_Session_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Session_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_Session_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_Session_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_Session_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_Session_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_Session_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_Session_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_Session_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_Session_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Session_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_Session_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_Session)
#define TC_DEF_TC_Evolution_Mail_Session 1
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Session_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_objref,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
"Session",
"IDL:Evolution/Mail/Session:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_Store_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_Store_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_Store_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_Store_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_Store_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_Store_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_Store_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_Store_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_Store_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_Store_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_Store_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_Store_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Store_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_Store_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Store_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_Store_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_Store_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_Store_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_Store_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_Store_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_Store_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_Store_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_Store_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Store_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_Store_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_Store)
#define TC_DEF_TC_Evolution_Mail_Store 1
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Store_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_objref,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
"Store",
"IDL:Evolution/Mail/Store:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif
#if ( (TC_IMPL_TC_Evolution_Mail_Folder_0 == 'E') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_1 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_2 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_3 == 'l') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_4 == 'u') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_5 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_6 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_7 == 'o') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_8 == 'n') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_9 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_10 == 'D') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_11 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_12 == 't') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_13 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_14 == 'S') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_15 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_16 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_17 == 'v') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_18 == 'e') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_19 == 'r') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_20 == '_') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_21 == 'M') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_22 == 'a') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_23 == 'i') \
&& (TC_IMPL_TC_Evolution_Mail_Folder_24 == 'l') \
) && !defined(TC_DEF_TC_Evolution_Mail_Folder)
#define TC_DEF_TC_Evolution_Mail_Folder 1
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBIT2_MAYBE_CONST struct CORBA_TypeCode_struct TC_Evolution_Mail_Folder_struct = {
{&ORBit_TypeCode_epv, ORBIT_REFCOUNT_STATIC},
CORBA_tk_objref,
0,
0,
ORBIT_ALIGNOF_CORBA_POINTER,
0,
0
,
NULL,
CORBA_OBJECT_NIL,
"Folder",
"IDL:Evolution/Mail/Folder:1.0",
NULL,
NULL,
-1,
0,
0, 0
};
#endif

#ifndef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
CORBA_unsigned_long Evolution_Mail_MessageStream__classid = 0;
#endif

#ifndef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
CORBA_unsigned_long Evolution_Mail_MessageIterator__classid = 0;
#endif

#ifndef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
CORBA_unsigned_long Evolution_Mail_SessionListener__classid = 0;
#endif

#ifndef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
CORBA_unsigned_long Evolution_Mail_StoreListener__classid = 0;
#endif

#ifndef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
CORBA_unsigned_long Evolution_Mail_FolderListener__classid = 0;
#endif

#ifndef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
CORBA_unsigned_long Evolution_Mail_Session__classid = 0;
#endif

#ifndef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
CORBA_unsigned_long Evolution_Mail_Store__classid = 0;
#endif

#ifndef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
CORBA_unsigned_long Evolution_Mail_Folder__classid = 0;
#endif

/* Interface type data */

static ORBit_IArg Evolution_Mail_MessageStream_next__arginfo [] = {
	{ TC_CORBA_long,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, "size" }
};
/* Exceptions */
static CORBA_TypeCode Evolution_Mail_MessageStream_next__exceptinfo [] = {
	TC_Evolution_Mail_MailException,
	NULL
};

#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBit_IMethod Evolution_Mail_MessageStream__imethods [] = {
	{
		{ 1, 1, Evolution_Mail_MessageStream_next__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 1, 1, Evolution_Mail_MessageStream_next__exceptinfo, FALSE },
		TC_Evolution_Mail_Buffer, "next", 4,
		0
}
, 	{
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, "dispose", 7,
		0
}
};static CORBA_string Evolution_Mail_MessageStream__base_itypes[] = {
"IDL:Bonobo/Unknown:1.0",
"IDL:omg.org/CORBA/Object:1.0"
};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBit_IInterface Evolution_Mail_MessageStream__iinterface = {
TC_Evolution_Mail_MessageStream,{2, 2, Evolution_Mail_MessageStream__imethods, FALSE},
{2, 2, Evolution_Mail_MessageStream__base_itypes, FALSE}
};

static ORBit_IArg Evolution_Mail_MessageIterator_next__arginfo [] = {
	{ TC_CORBA_long,  ORBit_I_ARG_IN | ORBit_I_COMMON_FIXED_SIZE, "limit" }
};
/* Exceptions */
static CORBA_TypeCode Evolution_Mail_MessageIterator_next__exceptinfo [] = {
	TC_Evolution_Mail_MailException,
	NULL
};

#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBit_IMethod Evolution_Mail_MessageIterator__imethods [] = {
	{
		{ 1, 1, Evolution_Mail_MessageIterator_next__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 1, 1, Evolution_Mail_MessageIterator_next__exceptinfo, FALSE },
		TC_Evolution_Mail_MessageInfos, "next", 4,
		0
}
, 	{
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, "dispose", 7,
		0
}
};static CORBA_string Evolution_Mail_MessageIterator__base_itypes[] = {
"IDL:Bonobo/Unknown:1.0",
"IDL:omg.org/CORBA/Object:1.0"
};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBit_IInterface Evolution_Mail_MessageIterator__iinterface = {
TC_Evolution_Mail_MessageIterator,{2, 2, Evolution_Mail_MessageIterator__imethods, FALSE},
{2, 2, Evolution_Mail_MessageIterator__base_itypes, FALSE}
};

static ORBit_IArg Evolution_Mail_SessionListener_changed__arginfo [] = {
	{ TC_Evolution_Mail_Session,  ORBit_I_ARG_IN , "session" },
	{ TC_Evolution_Mail_SessionChanges,  ORBit_I_ARG_IN , "changes" }
};
static ORBit_IArg Evolution_Mail_SessionListener_shutdown__arginfo [] = {
	{ TC_Evolution_Mail_Session,  ORBit_I_ARG_IN , "session" }
};

#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBit_IMethod Evolution_Mail_SessionListener__imethods [] = {
	{
		{ 2, 2, Evolution_Mail_SessionListener_changed__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, "changed", 7,
		0 | ORBit_I_METHOD_1_WAY
}
, 	{
		{ 1, 1, Evolution_Mail_SessionListener_shutdown__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, "shutdown", 8,
		0 | ORBit_I_METHOD_1_WAY
}
};static CORBA_string Evolution_Mail_SessionListener__base_itypes[] = {
"IDL:Bonobo/Unknown:1.0",
"IDL:omg.org/CORBA/Object:1.0"
};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBit_IInterface Evolution_Mail_SessionListener__iinterface = {
TC_Evolution_Mail_SessionListener,{2, 2, Evolution_Mail_SessionListener__imethods, FALSE},
{2, 2, Evolution_Mail_SessionListener__base_itypes, FALSE}
};

static ORBit_IArg Evolution_Mail_StoreListener_changed__arginfo [] = {
	{ TC_Evolution_Mail_Store,  ORBit_I_ARG_IN , "store" },
	{ TC_Evolution_Mail_StoreChanges,  ORBit_I_ARG_IN , "changes" }
};

#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBit_IMethod Evolution_Mail_StoreListener__imethods [] = {
	{
		{ 2, 2, Evolution_Mail_StoreListener_changed__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, "changed", 7,
		0 | ORBit_I_METHOD_1_WAY
}
};static CORBA_string Evolution_Mail_StoreListener__base_itypes[] = {
"IDL:Bonobo/Unknown:1.0",
"IDL:omg.org/CORBA/Object:1.0"
};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBit_IInterface Evolution_Mail_StoreListener__iinterface = {
TC_Evolution_Mail_StoreListener,{1, 1, Evolution_Mail_StoreListener__imethods, FALSE},
{2, 2, Evolution_Mail_StoreListener__base_itypes, FALSE}
};

static ORBit_IArg Evolution_Mail_FolderListener_changed__arginfo [] = {
	{ TC_Evolution_Mail_Folder,  ORBit_I_ARG_IN , "folder" },
	{ TC_Evolution_Mail_FolderChanges,  ORBit_I_ARG_IN , "changes" }
};

#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBit_IMethod Evolution_Mail_FolderListener__imethods [] = {
	{
		{ 2, 2, Evolution_Mail_FolderListener_changed__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, "changed", 7,
		0 | ORBit_I_METHOD_1_WAY
}
};static CORBA_string Evolution_Mail_FolderListener__base_itypes[] = {
"IDL:Bonobo/Unknown:1.0",
"IDL:omg.org/CORBA/Object:1.0"
};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBit_IInterface Evolution_Mail_FolderListener__iinterface = {
TC_Evolution_Mail_FolderListener,{1, 1, Evolution_Mail_FolderListener__imethods, FALSE},
{2, 2, Evolution_Mail_FolderListener__base_itypes, FALSE}
};

static ORBit_IArg Evolution_Mail_Session_getProperties__arginfo [] = {
	{ TC_Evolution_Mail_PropertyNames,  ORBit_I_ARG_IN , "names" },
	{ TC_Evolution_Mail_Properties,  ORBit_I_ARG_OUT , "props" }
};
static ORBit_IArg Evolution_Mail_Session_getStores__arginfo [] = {
	{ TC_CORBA_string,  ORBit_I_ARG_IN , "pattern" },
	{ TC_Evolution_Mail_StoreListener,  ORBit_I_ARG_IN , "listener" }
};
/* Exceptions */
static CORBA_TypeCode Evolution_Mail_Session_getStores__exceptinfo [] = {
	TC_Evolution_Mail_MailException,
	NULL
};
static ORBit_IArg Evolution_Mail_Session_addListener__arginfo [] = {
	{ TC_Evolution_Mail_SessionListener,  ORBit_I_ARG_IN , "listener" }
};
static ORBit_IArg Evolution_Mail_Session_removeListener__arginfo [] = {
	{ TC_Evolution_Mail_SessionListener,  ORBit_I_ARG_IN , "listener" }
};

#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBit_IMethod Evolution_Mail_Session__imethods [] = {
	{
		{ 2, 2, Evolution_Mail_Session_getProperties__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
		TC_CORBA_boolean, "getProperties", 13,
		0| ORBit_I_COMMON_FIXED_SIZE
}
, 	{
		{ 2, 2, Evolution_Mail_Session_getStores__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 1, 1, Evolution_Mail_Session_getStores__exceptinfo, FALSE },
		TC_Evolution_Mail_StoreInfos, "getStores", 9,
		0
}
, 	{
		{ 1, 1, Evolution_Mail_Session_addListener__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, "addListener", 11,
		0
}
, 	{
		{ 1, 1, Evolution_Mail_Session_removeListener__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
TC_void, "removeListener", 14,
		0
}
};static CORBA_string Evolution_Mail_Session__base_itypes[] = {
"IDL:Bonobo/Unknown:1.0",
"IDL:omg.org/CORBA/Object:1.0"
};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBit_IInterface Evolution_Mail_Session__iinterface = {
TC_Evolution_Mail_Session,{4, 4, Evolution_Mail_Session__imethods, FALSE},
{2, 2, Evolution_Mail_Session__base_itypes, FALSE}
};

static ORBit_IArg Evolution_Mail_Store_getProperties__arginfo [] = {
	{ TC_Evolution_Mail_PropertyNames,  ORBit_I_ARG_IN , "names" },
	{ TC_Evolution_Mail_Properties,  ORBit_I_ARG_OUT , "props" }
};
static ORBit_IArg Evolution_Mail_Store_getFolders__arginfo [] = {
	{ TC_CORBA_string,  ORBit_I_ARG_IN , "pattern" },
	{ TC_Evolution_Mail_FolderListener,  ORBit_I_ARG_IN , "listener" }
};
/* Exceptions */
static CORBA_TypeCode Evolution_Mail_Store_getFolders__exceptinfo [] = {
	TC_Evolution_Mail_MailException,
	NULL
};
static ORBit_IArg Evolution_Mail_Store_sendMessage__arginfo [] = {
	{ TC_Evolution_Mail_MessageStream,  ORBit_I_ARG_IN , "msg" }
};
/* Exceptions */
static CORBA_TypeCode Evolution_Mail_Store_sendMessage__exceptinfo [] = {
	TC_Evolution_Mail_MailException,
	NULL
};

#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBit_IMethod Evolution_Mail_Store__imethods [] = {
	{
		{ 2, 2, Evolution_Mail_Store_getProperties__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
		TC_CORBA_boolean, "getProperties", 13,
		0| ORBit_I_COMMON_FIXED_SIZE
}
, 	{
		{ 2, 2, Evolution_Mail_Store_getFolders__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 1, 1, Evolution_Mail_Store_getFolders__exceptinfo, FALSE },
		TC_Evolution_Mail_FolderInfos, "getFolders", 10,
		0
}
, 	{
		{ 1, 1, Evolution_Mail_Store_sendMessage__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 1, 1, Evolution_Mail_Store_sendMessage__exceptinfo, FALSE },
TC_void, "sendMessage", 11,
		0
}
};static CORBA_string Evolution_Mail_Store__base_itypes[] = {
"IDL:Bonobo/Unknown:1.0",
"IDL:omg.org/CORBA/Object:1.0"
};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBit_IInterface Evolution_Mail_Store__iinterface = {
TC_Evolution_Mail_Store,{3, 3, Evolution_Mail_Store__imethods, FALSE},
{2, 2, Evolution_Mail_Store__base_itypes, FALSE}
};

static ORBit_IArg Evolution_Mail_Folder_getProperties__arginfo [] = {
	{ TC_Evolution_Mail_PropertyNames,  ORBit_I_ARG_IN , "names" },
	{ TC_Evolution_Mail_Properties,  ORBit_I_ARG_OUT , "props" }
};
static ORBit_IArg Evolution_Mail_Folder_getMessages__arginfo [] = {
	{ TC_CORBA_string,  ORBit_I_ARG_IN , "pattern" }
};
/* Exceptions */
static CORBA_TypeCode Evolution_Mail_Folder_getMessages__exceptinfo [] = {
	TC_Evolution_Mail_MailException,
	NULL
};
static ORBit_IArg Evolution_Mail_Folder_changeMessages__arginfo [] = {
	{ TC_Evolution_Mail_MessageInfoSets,  ORBit_I_ARG_IN , "infos" }
};
/* Exceptions */
static CORBA_TypeCode Evolution_Mail_Folder_changeMessages__exceptinfo [] = {
	TC_Evolution_Mail_MailException,
	NULL
};
static ORBit_IArg Evolution_Mail_Folder_getMessage__arginfo [] = {
	{ TC_CORBA_string,  ORBit_I_ARG_IN , "uid" }
};
/* Exceptions */
static CORBA_TypeCode Evolution_Mail_Folder_getMessage__exceptinfo [] = {
	TC_Evolution_Mail_MailException,
	NULL
};
static ORBit_IArg Evolution_Mail_Folder_appendMessage__arginfo [] = {
	{ TC_Evolution_Mail_MessageInfoSet,  ORBit_I_ARG_IN , "info" },
	{ TC_Evolution_Mail_MessageStream,  ORBit_I_ARG_IN , "msg" }
};
/* Exceptions */
static CORBA_TypeCode Evolution_Mail_Folder_appendMessage__exceptinfo [] = {
	TC_Evolution_Mail_MailException,
	NULL
};

#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBit_IMethod Evolution_Mail_Folder__imethods [] = {
	{
		{ 2, 2, Evolution_Mail_Folder_getProperties__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 0, 0, NULL, FALSE },
		TC_CORBA_boolean, "getProperties", 13,
		0| ORBit_I_COMMON_FIXED_SIZE
}
, 	{
		{ 1, 1, Evolution_Mail_Folder_getMessages__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 1, 1, Evolution_Mail_Folder_getMessages__exceptinfo, FALSE },
		TC_Evolution_Mail_MessageIterator, "getMessages", 11,
		0
}
, 	{
		{ 1, 1, Evolution_Mail_Folder_changeMessages__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 1, 1, Evolution_Mail_Folder_changeMessages__exceptinfo, FALSE },
TC_void, "changeMessages", 14,
		0
}
, 	{
		{ 1, 1, Evolution_Mail_Folder_getMessage__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 1, 1, Evolution_Mail_Folder_getMessage__exceptinfo, FALSE },
		TC_Evolution_Mail_MessageStream, "getMessage", 10,
		0
}
, 	{
		{ 2, 2, Evolution_Mail_Folder_appendMessage__arginfo, FALSE },
		{ 0, 0, NULL, FALSE },
		{ 1, 1, Evolution_Mail_Folder_appendMessage__exceptinfo, FALSE },
TC_void, "appendMessage", 13,
		0
}
};static CORBA_string Evolution_Mail_Folder__base_itypes[] = {
"IDL:Bonobo/Unknown:1.0",
"IDL:omg.org/CORBA/Object:1.0"
};
#ifdef ORBIT_IDL_C_IMODULE_Evolution_DataServer_Mail
static
#endif
ORBit_IInterface Evolution_Mail_Folder__iinterface = {
TC_Evolution_Mail_Folder,{5, 5, Evolution_Mail_Folder__imethods, FALSE},
{2, 2, Evolution_Mail_Folder__base_itypes, FALSE}
};

